@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.4.1"
+    version = "1.4.2"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -125,7 +125,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         payload = f"## {custom_keyword}\n\n" if custom_keyword else ""
         payload = f"{payload} > 项目名称: {project.name} \n\n"
-        payload = f"{payload} > status: {group.status} \n\n"
+        # payload = f"{payload} > status: {group.status} \n\n"
         payload = f"{payload} > 告警次数: {group.times_seen} \n\n"
         payload = f"{payload} > 查看详情: <font color=blue>[{group.title}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
@@ -149,13 +149,12 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         # 获取预设的阀值
         counts = self.get_option("warning_counts", project)
-        #  or int(counts) > int(group.times_seen)
-        if int(group.status) != 0:
-            data = {
+        if int(group.status) == 0:
+            data_1 = {
                 "msgtype": "markdown",
                 "markdown": {
-                    "title": "Hi",
-                    "text": "Hello!" + '\n\n' + '@' + '@'.join(phone)
+                    "title": group.title,
+                    "text": payload + '\n\n' + '@' + '@'.join(phone)
                 },
                 "at": {
                     "atMobiles": notify_user,
@@ -163,8 +162,11 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
                 }
 
             }
-        else:
-            data = {
+            for webhook_url in self.get_webhook_urls(group.project):
+                requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
+
+        if int(group.times_seen) > int(counts):
+            data_2 = {
                 "msgtype": "markdown",
                 "markdown": {
                     "title": group.title,
@@ -177,5 +179,5 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
             }
 
-        for webhook_url in self.get_webhook_urls(group.project):
-            requests.post(webhook_url, data=json.dumps(data), headers=headers)
+            for webhook_url in self.get_webhook_urls(group.project):
+                requests.post(webhook_url, data=json.dumps(data_2), headers=headers)
